@@ -1,9 +1,10 @@
 """Module to provide class to decorate models as tables."""
-from typing import Callable, Type
+from typing import Callable, Optional, Type
 
 from cassandra.cluster import Session
+from pydantic import BaseModel
 
-from pyssandra._query_builder import ModelType, QueryBuilder
+from pyssandra._query_builder import ModelType, QueryBuilder, TableMetadata
 
 
 class Pyssandra:
@@ -15,9 +16,10 @@ class Pyssandra:
         :param session: Cassandra session to use.
         :param keyspace: Keyspace of the tables.
         """
+        self.models: list[Type[BaseModel]] = []
         self._session = session
         self._keyspace = keyspace
-        self._model_type_to_query_builder: dict[ModelType, QueryBuilder] = {}
+        self._model_type_to_query_builder: dict[Type[BaseModel], QueryBuilder] = {}
 
     def __getitem__(self, item: Type[ModelType]) -> QueryBuilder[ModelType]:
         """Get a `QueryBuilder` for the given model.
@@ -27,15 +29,26 @@ class Pyssandra:
         """
         return self._model_type_to_query_builder[item]
 
-    def table(self, keys: list[str]) -> Callable[[Type[ModelType]], Type[ModelType]]:
+    def table(
+        self,
+        partition_keys: list[str],
+        clustering_keys: Optional[list[str]] = None,
+        index: Optional[list[str]] = None,
+    ) -> Callable[[Type[ModelType]], Type[ModelType]]:
         """Register a model as a database table.
 
-        :param keys: Table partition keys.
+        :param partition_keys: Table partition keys.
+        :param clustering_keys: Table clustering keys.
+        :param index: Table indexed columns.
         :return: Wrapper for the decorated table.
         """
+        table_meta = TableMetadata(
+            partition_keys=partition_keys, clustering_keys=clustering_keys, index=index
+        )
 
         def _wrapper(cls: Type[ModelType]) -> Type[ModelType]:
-            query_builder = QueryBuilder(self._session, self._keyspace, cls, keys)
+            self.models.append(cls)
+            query_builder = QueryBuilder(self._session, self._keyspace, cls, table_meta)
             self._model_type_to_query_builder[cls] = query_builder
             return cls
 
